@@ -29,11 +29,11 @@ ignore = ['core', 'CVS']
 def dummy(v):
     pass
 
-def make_meta_file(file, url, piece_len_exp = 18, 
+def make_meta_file(file, url, piece_len_exp, 
         flag = Event(), progress = dummy, progress_percent=1, comment = None, target = None):
     piece_length = 2 ** piece_len_exp
     a, b = split(file)
-    if target == '':
+    if not target:
         if b == '':
             f = a + '.torrent'
         else:
